@@ -8,7 +8,9 @@ pub use gloo_console as console;
 pub use gloo_dialogs as dialogs;
 pub use gloo_events as events;
 pub use gloo_file as file;
+pub use gloo_history as history;
 pub use gloo_render as render;
 pub use gloo_storage as storage;
 pub use gloo_timers as timers;
 pub use gloo_utils as utils;
+pub use gloo_worker as worker;
